==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/classgko_1_1CudaExecutor.js <==
var classgko_1_1CudaExecutor =
[
    [ "get_blas_handle", "classgko_1_1CudaExecutor.html#a1251802b1fa34107d00927e8bd3bd9a2", null ],
    [ "get_closest_numa", "classgko_1_1CudaExecutor.html#a23a13ee1b82ea850660da25376d6cf4e", null ],
    [ "get_closest_pus", "classgko_1_1CudaExecutor.html#a14c70ca95b76c22ec3c5857e04cfea8e", null ],
    [ "get_cublas_handle", "classgko_1_1CudaExecutor.html#aae42e3ae7e95c21092afdc198adacc8a", null ],
    [ "get_cusparse_handle", "classgko_1_1CudaExecutor.html#a7abd86b1590597a0f6a097585a446006", null ],
    [ "get_description", "classgko_1_1CudaExecutor.html#ac429a47e4fab2f11df0dd09fc9652a19", null ],
    [ "get_device_id", "classgko_1_1CudaExecutor.html#a7cfa915eadd2329eb897dc1ee2712488", null ],
    [ "get_major_version", "classgko_1_1CudaExecutor.html#a3868f53f82b6398acb1ba1f9647a6e46", null ],
    [ "get_master", "classgko_1_1CudaExecutor.html#a8999e5a4598d224fadc6c0047ed6ca17", null ],
    [ "get_master", "classgko_1_1CudaExecutor.html#a6466705137b8ac3974734837c7730d74", null ],
    [ "get_minor_version", "classgko_1_1CudaExecutor.html#aa7d7a5cd7aeb38b8ab8fe3e4d1538481", null ],
    [ "get_num_multiprocessor", "classgko_1_1CudaExecutor.html#a449c2bf9c51b58a04fdb8b4a73377820", null ],
    [ "get_num_warps", "classgko_1_1CudaExecutor.html#aa9d77db0b87322a8bef12380029b5310", null ],
    [ "get_num_warps_per_sm", "classgko_1_1CudaExecutor.html#a245c1c35a18e6534d87ef6e9cad24f7c", null ],
    [ "get_sparselib_handle", "classgko_1_1CudaExecutor.html#a0d41c86eba6b19b906bf3044c8f5bec2", null ],
    [ "get_stream", "classgko_1_1CudaExecutor.html#a935159e4376a4cd01408af020d0fc627", null ],
    [ "get_warp_size", "classgko_1_1CudaExecutor.html#a6a3894e9f4d98b5f7523e067c88ef521", null ],
    [ "run", "classgko_1_1CudaExecutor.html#a294787f033b02fd013af087d02a4ae1b", null ],
    [ "run", "classgko_1_1CudaExecutor.html#a4fdbf8100b039d3858634bf9c502f5d7", null ],
    [ "run", "classgko_1_1CudaExecutor.html#abe906f109824da54447e504ff88aa97f", null ],
    [ "synchronize", "classgko_1_1CudaExecutor.html#a903cf7e3460b14677c0bce5ca08a1b81", null ]
];

==> ginkgo-hpc-docs-1.11.0-3-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/classgko_1_1CudaExecutor.js <==
var classgko_1_1CudaExecutor =
[
    [ "get_blas_handle", "classgko_1_1CudaExecutor.html#a1251802b1fa34107d00927e8bd3bd9a2", null ],
    [ "get_closest_numa", "classgko_1_1CudaExecutor.html#a23a13ee1b82ea850660da25376d6cf4e", null ],
    [ "get_closest_pus", "classgko_1_1CudaExecutor.html#a14c70ca95b76c22ec3c5857e04cfea8e", null ],
    [ "get_compute_capability", "classgko_1_1CudaExecutor.html#a0e4dc9ea3719ebd8fe9e393629bf6c7c", null ],
    [ "get_cublas_handle", "classgko_1_1CudaExecutor.html#aae42e3ae7e95c21092afdc198adacc8a", null ],
    [ "get_cusparse_handle", "classgko_1_1CudaExecutor.html#a7abd86b1590597a0f6a097585a446006", null ],
    [ "get_description", "classgko_1_1CudaExecutor.html#ac429a47e4fab2f11df0dd09fc9652a19", null ],
    [ "get_device_id", "classgko_1_1CudaExecutor.html#a7cfa915eadd2329eb897dc1ee2712488", null ],
    [ "get_major_version", "classgko_1_1CudaExecutor.html#a3868f53f82b6398acb1ba1f9647a6e46", null ],
    [ "get_master", "classgko_1_1CudaExecutor.html#a8999e5a4598d224fadc6c0047ed6ca17", null ],
    [ "get_master", "classgko_1_1CudaExecutor.html#a6466705137b8ac3974734837c7730d74", null ],
    [ "get_minor_version", "classgko_1_1CudaExecutor.html#aa7d7a5cd7aeb38b8ab8fe3e4d1538481", null ],
    [ "get_num_multiprocessor", "classgko_1_1CudaExecutor.html#a449c2bf9c51b58a04fdb8b4a73377820", null ],
    [ "get_num_warps", "classgko_1_1CudaExecutor.html#aa9d77db0b87322a8bef12380029b5310", null ],
    [ "get_num_warps_per_sm", "classgko_1_1CudaExecutor.html#a245c1c35a18e6534d87ef6e9cad24f7c", null ],
    [ "get_sparselib_handle", "classgko_1_1CudaExecutor.html#a0d41c86eba6b19b906bf3044c8f5bec2", null ],
    [ "get_stream", "classgko_1_1CudaExecutor.html#a935159e4376a4cd01408af020d0fc627", null ],
    [ "get_warp_size", "classgko_1_1CudaExecutor.html#a6a3894e9f4d98b5f7523e067c88ef521", null ],
    [ "run", "classgko_1_1CudaExecutor.html#a294787f033b02fd013af087d02a4ae1b", null ],
    [ "run", "classgko_1_1CudaExecutor.html#a4fdbf8100b039d3858634bf9c502f5d7", null ],
    [ "run", "classgko_1_1CudaExecutor.html#abe906f109824da54447e504ff88aa97f", null ],
    [ "synchronize", "classgko_1_1CudaExecutor.html#a903cf7e3460b14677c0bce5ca08a1b81", null ]
];
